# Caterpillar Diagram

> A generic innovative visualization technique for univariate time-series data capable of
> forecasting the next-state transition using Markov chains.

This is a software implementation of the proposed Caterpillar Diagram in the research
article titled [__"An innovative color-coding scheme for terrorism threat advisory
system".__](https://doi.org/10.1177/20597991221144577)

Authors:
1. [Prabal Pratap Singh](https://orcid.org/0000-0002-0738-7629)
2. [Prof. Deepu Philip](https://orcid.org/0000-0002-4607-9020)